@@ -26,17 +26,36 @@ class InterstateError:
         return self._stacktrace
 
     def __repr__(self) -> str:
-        return "InterstateError(type={}, message={}, stacktrace={})".format(self._error_type, self._error_message, self._stacktrace)
+        return "InterstateError(type={}, message={}, stacktrace={})".format(self._error_type, self._error_message,
+                                                                            self._stacktrace)
 
 
 class ErrorAssembly:
+    """
+    Assembles serializable InterstateErrors from Exceptions
+    """
+    # Common error types:
+    SERIALIZATION_ERROR_TYPE = "SerializationError"
+    DESERIALIZATION_ERROR_TYPE = "DeserializationError"
 
     @staticmethod
-    def to_error(e: Exception) -> InterstateError:
-        return InterstateError(
-            e.__class__.__name__,
-            ErrorAssembly.exc_message(e),
-            ErrorAssembly.get_stacktrace(50))
+    def to_error(error_type: str, e: Exception) -> InterstateError:
+        """
+
+        :param error_type: some string identifying the type of the error
+        :param e:
+        :return:
+        """
+        return InterstateError(error_type, ErrorAssembly.exc_message(e), ErrorAssembly.get_stacktrace(50))
+
+    @staticmethod
+    def exc_to_error(e: Exception) -> InterstateError:
+        """
+        Transforms an exception an an serializable Interstate Error
+        :param e:
+        :return:
+        """
+        return ErrorAssembly.to_error(e.__class__.__name__, e)
 
     @staticmethod
     def to_on_error(multiplex_message: MultiplexMessage) -> InterstateWireMessage:
