@@ -2,7 +2,6 @@ from asyncio import Queue
 
 from interstate_py.connection_agent import ConnectionAgentBase
 from interstate_py.control.worker_task import AIOWorkerTask
-from interstate_py.error.deserialization_exception import DeserializationException
 from interstate_py.error.error_assembly import ErrorAssembly
 from interstate_py.interstate_message import InterstateWireMessageType
 from interstate_py.log_factory import LogFactory
@@ -42,7 +41,8 @@ class StreamDemultiplexer(AIOWorkerTask):
                 self._log.warn("[IN][NEXT] - Could not deserialize incoming message: %s", ErrorAssembly.exc_message(e))
                 await self._outbound_queue.put(
                     MultiplexMessage(message.identity.decode(), InterstateWireMessageType.ERROR,
-                                     ErrorAssembly.to_error(DeserializationException("Could not deserialize:" + e.__repr__()))))
+                                     ErrorAssembly.to_error(ErrorAssembly.DESERIALIZATION_ERROR_TYPE,
+                                                            e)))
         elif message.type == InterstateWireMessageType.ERROR:
             self._log.warn("[IN][ERROR] - {}".format(message))
             connection.inbound_stream().on_error(Exception("Error"))
