@@ -75,6 +75,7 @@ class StreamMultiplexer(AIOWorkerTask):
             return InterstateWireMessage(multiplex_message.identity.encode(), InterstateWireMessageType.header("next"),
                                          serialized_payload)
         except Exception as e:
-            self._log.error("Something went wrong during serialization")
+            self._log.error("[ERROR] Could not serialize outgoing message: %s", str(multiplex_message.payload))
             await self._raw_outbound_queue.put(ErrorAssembly.to_on_error(
-                MultiplexMessage(multiplex_message.identity, InterstateWireMessageType.ERROR, ErrorAssembly.to_error(e))))
+                MultiplexMessage(multiplex_message.identity, InterstateWireMessageType.ERROR,
+                                 ErrorAssembly.to_error(ErrorAssembly.SERIALIZATION_ERROR_TYPE, e))))
